summaryrefslogtreecommitdiffstats
path: root/database/rrd.h
diff options
context:
space:
mode:
authorStelios Fragkakis <52996999+stelfrag@users.noreply.github.com>2021-03-22 09:47:22 +0200
committerGitHub <noreply@github.com>2021-03-22 09:47:22 +0200
commit65bc43d9cbc17d6ac356672cdc24ffe74fc463e5 (patch)
tree3c6b378578d9dfd911555cdda706529fb2f1b525 /database/rrd.h
parent0b0748ee4f9d573e4b741f37a0fa2d158c37599e (diff)
Add data query support for archived charts (#10771)
Diffstat (limited to 'database/rrd.h')
-rw-r--r--database/rrd.h12
1 files changed, 11 insertions, 1 deletions
diff --git a/database/rrd.h b/database/rrd.h
index 17ab610107..59d0501bdb 100644
--- a/database/rrd.h
+++ b/database/rrd.h
@@ -41,10 +41,17 @@ struct pg_cache_page_index;
#include "aclk/aclk.h"
#endif
+enum {
+ CONTEXT_FLAGS_ARCHIVE = 0x01,
+ CONTEXT_FLAGS_CHART = 0x02,
+ CONTEXT_FLAGS_CONTEXT = 0x04
+};
+
struct context_param {
RRDDIM *rd;
time_t first_entry_t;
time_t last_entry_t;
+ uint8_t flags;
};
#define META_CHART_UPDATED 1
@@ -533,7 +540,10 @@ struct rrdset {
size_t counter; // the number of times we added values to this database
size_t counter_done; // the number of times rrdset_done() has been called
- time_t last_accessed_time; // the last time this RRDSET has been accessed
+ union {
+ time_t last_accessed_time; // the last time this RRDSET has been accessed
+ time_t last_entry_t; // the last_entry_t computed for transient RRDSET
+ };
time_t upstream_resync_time; // the timestamp up to which we should resync clock upstream
char *plugin_name; // the name of the plugin that generated this